#
# spec file for package emacs-auctex
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           emacs-auctex
BuildRequires:  emacs-x11
BuildRequires:  ghostscript_any
BuildRequires:  texlive
BuildRequires:  texlive-latex
Obsoletes:      ge_auc
Provides:       auc-tex
Provides:       auctex
Provides:       ge_auc
Requires:       emacs
Requires:       texlive-latex
Requires:       texlive-tools
%if %suse_version > 1220
BuildRequires:  makeinfo
BuildRequires:  texinfo
BuildRequires:  texlive-collection-latexextra
BuildRequires:  texlive-tex
BuildRequires:  texlive-texinfo
%endif
Version:        11.87
Release:        12.23
Summary:        AUC TeX: An Emacs Extension
License:        GPL-2.0+
Group:          Productivity/Editors/Emacs
Source:         ftp://ftp.gnu.org/pub/gnu/auctex/auctex-%{version}.tar.gz
Url:            http://www.gnu.org/software/auctex
Patch:          auctex-11.87.dif
Patch2:         auctex-11.86-dinbrief.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
These macros make it easier for you to write TeX documents with GNU
Emacs.	Documentation can be found under:

/usr/share/doc/packages/emacs-auctex/

and in the dvi files math-ref.dvi and tex-ref.dvi (reference cards) and
in the info file auctex in emacs info-mode.

AuC TeX is integrated in XEmacs 19.15 and higher, so these packages may
not be installed concurrently.	Note that the binary formats of the
byte-compiled lisp files of the two emacs editors are incompatible, so
you cannot use this package for XEmacs.

%define _sitedir %{_datadir}/emacs/site-lisp
%define _aucdir  %{_sitedir}/auctex

%prep
%setup -n auctex-%{version}
%patch
%patch2 -p1

%build
    unset ${!LC_*}
    LANG=en_US.UTF-8
    export LANG
    rm -rf /tmp/auctex
    mkdir  /tmp/auctex
    mkdir -p /tmp/auctex/doc/preview
    mkdir -p /tmp/auctex/latex/preview
    %configure \
	--docdir=%{_defaultdocdir}/%name	\
	--with-emacs				\
	--with-lispdir=%{_sitedir}		\
	--with-auto-dir=%{_aucdir}/auto		\
	--with-texmf-dir=%{_datadir}/texmf	\
	--with-doc-dir=/tmp/auctex/doc/preview	\
	--with-tex-dir=/tmp/auctex/latex/preview
    find , -name '*.elc' | xargs -r rm -f
    make %{?_smp_mflags}
    make -C doc clean
    make -C doc %{?_smp_mflags}
    make -C doc extradist
    rm -rf /tmp/auctex

%install
    export LC_CTYPE=ISO-8859-1
    mkdir -p %{buildroot}%{_sitedir}/site-start.d
    make install DESTDIR=%{buildroot}
    rm -rf %{buildroot}%{_aucdir}/auto
    pushd %{buildroot}%{_aucdir}/
	emacs --no-site -batch -L %{buildroot}%{_sitedir}/auctex 		\
	    --eval '(setq TeX-lisp-directory "%{buildroot}%{_aucdir}")'		\
	    --eval '(setq TeX-auto-global "%{buildroot}%{_aucdir}/auto")'	\
	    -l %{buildroot}%{_sitedir}/tex-site.el -f TeX-auto-generate-global
    popd
    touch %{buildroot}%{_aucdir}/auto/.nosearch
    find %{buildroot}%{_aucdir}/auto/ -name '*.elc' | xargs -r rm -f
    cat <<-EOF > %{buildroot}%{_sitedir}/suse-start-auctex.el
	;;; suse-start-auctex.el
	;;
	;; This is used for starting up AUCTeX
	;; See (info "(auctex)Introduction") on how to disable AUCTeX.
	;;
	(load "auctex.el" nil t t)
	EOF
    cat <<-EOF > %{buildroot}%{_sitedir}/suse-start-preview-latex.el
	;;; suse-start-preview-latex.el
	;;
	;; This is used for starting up preview-latex of AUCTeX
	;; See (info "(auctex)Introduction") on how to disable AUCTeX.
	;;
	(load "preview-latex.el" nil t t)
	EOF
    #
    # Preview is part of te_latex
    #
    rm -rf %{buildroot}/tmp/auctex
%define info_files auctex.info preview-latex.info

%post
for f in %info_files; do
 %install_info --info-dir=%{_infodir} %{_infodir}/$f.gz
done

%postun
for f in %info_files; do
  %install_info_delete --info-dir=%{_infodir} %{_infodir}/$f.gz
done

%files
%defattr(-, root, root)
%doc README COPYING doc/*.pdf CHANGES ChangeLog
%dir %{_sitedir}/
%dir %{_aucdir}/
%dir %{_aucdir}/auto/
%dir %{_aucdir}/images/
%dir %{_aucdir}/style/
%doc %{_infodir}/*.info*.gz
%{_aucdir}/*.el
%{_aucdir}/*.elc
%{_aucdir}/.nosearch
%{_aucdir}/auto/*.el
%{_aucdir}/images/*.xpm
%{_aucdir}/images/*.xbm
%{_aucdir}/style/*.el
%{_aucdir}/style/*.elc
%{_aucdir}/auto/.nosearch
%{_aucdir}/style/.nosearch
%config %{_sitedir}/suse-start*.el
%config %{_sitedir}/tex-site.el
%config %{_sitedir}/site-start.d/auctex.el
%config %{_sitedir}/site-start.d/preview-latex.el

%changelog
* Tue Oct  7 2014 crrodriguez@opensuse.org
- No shared libraries are needed for build, this is a noarch
  package.
* Wed Sep 25 2013 werner@suse.de
- Make it build again as we have now a site-start.d below site-lisp
* Fri Jun  7 2013 werner@suse.de
- Use latest upstream update of dinbrief.el
* Thu Jun  6 2013 werner@suse.de
- Update to auctex 11.87
  * Includes the preview fix for ghostscript
  * Includes the changes for font-late.elc
- Remove auctex-11.86-font-latex.5.194.patch
* Thu Jun  6 2013 werner@suse.de
- Add patch auctex-11.86-font-latex.5.194.patch from upstream to
  make GNU emacs 24.3 silent about font-late.elc (reported by
  Johannes Roth)
* Fri Feb 22 2013 werner@suse.de
- Make dinbrief work again
* Mon Jul 23 2012 werner@suse.de
- Use texlive-texinfo for build and add also all LaTeX styles to
  be scanned during AucTeX build.
- Use texinfo *and* makeinfo for build as both are required
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Oct 13 2010 werner@suse.de
- Allow also to read PDF file its self to be able to generate the
  descriptions of those file (based on patch of Dieter Jurzitza)
* Wed Aug 11 2010 werner@suse.de
- Make fix for bnc#623719 more flexible
* Sun Jul 25 2010 aj@suse.de
- Package all info files.
* Wed Jul 21 2010 werner@suse.de
- Update to auctex 11.86
  * Parsing of LaTeX output was improved.  It is now less likely that
    AUCTeX opens a non-existent file upon calling `TeX-next-error'; a
    problem for example encountered when using MiKTeX 2.8.  In addition
    quoted file names as emitted by MiKTeX are now supported.
  * A new framework for the definition and selection of viewers was
    implemented.  If you have customizations regarding viewers you
    will have to redo them in this new framework or reenable the old
    one.  See the section on viewers in the manual for details.
  * Comprehensive editing support for PSTricks was added.
  * Support for various LaTeX packages was added, e.g. `tabularx',
    `CJK', and `hyperref'.
  * An easy way to switch between TeX engines (PDFTeX, LuaTeX, XeTeX,
    Omega) was added.
  * Support for SyncTeX was added.  This involves the command line
    options for LaTeX and the viewer.
  * Folding can now be customized to use macro arguments as replacement
    text.
  * `preview.sty' now works with XeTeX.
  * A lot of smaller and larger bugs have been squashed.
* Wed Jul 21 2010 werner@suse.de
- Fix the usage of ghostscript for preview mode also switch over to
  faster dvipng mode which is much faster than ghostscript (bnc#623719)
* Mon Mar 17 2008 werner@suse.de
- Use texlive-tools instead of lacheck
* Tue Mar 11 2008 werner@suse.de
- Avoid overlong file lists use find and xargs instead
* Mon Mar 10 2008 werner@suse.de
- Make it work with texlive and texlive-latex
- Update to auctec 11.85
  + News in 11.85
  * Font locking has been improved significantly.
  * The license was updated to GPLv3.
  * Support for the nomencl, flashcards and comment LaTeX packages
    as well as the Icelandic language option of babel were added.
  * Support for folding of math macros was added.
  * Lots of minor bugs in features and documentation fixed.
  + News in 11.84
  * AUCTeX has been changed in order to accommodate file names
    containing spaces.
  * Support for folding of comments was added.
  * The TeX tool bar is now available and enabled by default in
    plain TeX mode.
  * Bug fix in the display of math subscripts and superscripts.
  * Bug fix `TeX-doc' for Emacs 21.
  * There has been quite a number of other bug fixes to various
    features and documentation across the board.
* Sun Apr 29 2007 aj@suse.de
- Fix Requires for texlive.
* Fri Apr 27 2007 werner@suse.de
- Make it build with texlive
* Fri Mar  2 2007 werner@suse.de
- No binary anymore is no architecture
* Thu Jun 29 2006 werner@suse.de
- Update to 11.83
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 werner@suse.de
- Update to 11.55
- Use newer dinbrief.el
- Build as non root user
* Tue Sep 21 2004 werner@suse.de
- encl, cc ... should be included within letter environment
* Fri Jan  9 2004 werner@suse.de
- Update to 11.14
* Tue Jul  2 2002 werner@suse.de
- Update to auc-tex 11.11 (bug #16605)
* Fri Feb 22 2002 werner@suse.de
- Make conditionals in font-lock work with emacs 21.1
* Sat Feb  9 2002 ro@suse.de
- removed te_fr from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Nov  8 2001 werner@suse.de
- Add all libs reqired by emacs to neededforbuild
* Fri Mar 16 2001 werner@suse.de
- Mark tex-site.el as config file
* Tue Mar 13 2001 ro@suse.de
- added emacs-x11 to neededforbuild
* Wed Mar  7 2001 werner@suse.de
- Rename package to emacs-auctex
* Fri Nov 17 2000 ro@suse.de
- ge_exec -> emacs
* Tue Jun  6 2000 ro@suse.de
- doc relocation
* Fri Feb 25 2000 werner@suse.de
- Change dvips print command to be able to avoid config.lp
  within teTeX package
* Thu Feb 24 2000 werner@suse.de
- Make it work for all teTeX versions
  - /usr/info -> /usr/share/info
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 13 1999 werner@suse.de
- Make dinbrief.sty comaptible to xemacs
* Thu Jul  8 1999 werner@suse.de
- New version 9.9p
  - A few changes to my dinbrief.sty
* Thu Apr 15 1999 werner@suse.de
- added export LC_CTYPE=ISO-8859-1 to install section
* Wed Nov 18 1998 werner@suse.de
- Change file list because of the new tetex version
* Mon Jul 27 1998 bs@suse.de
- added export LC_CTYPE=ISO-8859-1 to build section - emacs needs it.
* Fri Jul 10 1998 bs@suse.de
- added xaw3d to neededforbuild (ge_exec needs it)
* Mon Jun  2 1997 werner@suse.de
- removed /usr/info/latex*.gz ... because it's included in tetex
* Wed May 28 1997 werner@suse.de
- New version 9.7p
  - Skip X-emacs: xemacs-19.15 has an integrated
  auctex version 9.7l
  - Added ltx-help.el, latex(2e).info due
  the auctex-9.7p does not has it anymore
* Thu Jan  2 1997 werner@suse.de
- auctex: Version 9.5a für GNU-emacs und X-emacs
